==> soliq_id-1.4.27.tar.gz: lib/src/data/dio/dio_module.dart <==
import 'package:dio/dio.dart';
import 'package:injectable/injectable.dart';

import 'api_interceptor.dart';

const _requestTimeoutInMilliseconds = 10000;
@module
abstract class DioModule {
  @Named("Host")
  String get host => 'api.myfaceid.uz';

  @Named("TestHost")
  String get testHost => 'api.myfaceid.uz';

  @Named("Environment")
  bool get isTest => const bool.hasEnvironment("isTest");

  @singleton
  Future<Dio> getAuthorizedDioClient({
    @Named("Environment") required bool isTest,
    @Named("Host") required String host,
    @Named("TestHost") required String testHost,
  }) async {
    String _baseUrl = 'https://${isTest ? testHost : host}/';
    final authorizedDioClient = _createDioClient(_baseUrl);
    authorizedDioClient.interceptors.addAll([
      AuthorizedRequestInterceptor(
        authorizedDioClient,
      ),
    ]);
    return authorizedDioClient;
  }

  @Named("UnauthorizedClient")
  @singleton
  Future<Dio> getUnauthorizedDioClient({
    @Named("Environment") required bool isTest,
    @Named("Host") required String host,
    @Named("TestHost") required String testHost,
  }) async {
    String _baseUrl = 'https://${isTest ? testHost : host}/';
    final authorizedDioClient = _createDioClient(_baseUrl);
    authorizedDioClient.interceptors.addAll([
      AuthorizedRequestInterceptor(
        authorizedDioClient,
      ),
    ]);
    return authorizedDioClient;
  }

  Dio _createDioClient(String baseUrl) {
    final options = BaseOptions(
      baseUrl: baseUrl,
      receiveDataWhenStatusError: true,
      connectTimeout: const Duration(milliseconds: _requestTimeoutInMilliseconds),
      receiveTimeout: const Duration(milliseconds: _requestTimeoutInMilliseconds),
    );
    return Dio(options);
  }
}

==> soliq_id-1.4.36.tar.gz: lib/src/data/dio/dio_module.dart <==
import 'package:dio/dio.dart';
import 'package:injectable/injectable.dart';

import 'api_interceptor.dart';

const _requestTimeoutInMilliseconds = 10000;
@module
abstract class DioModule {
  @Named("Host")
  String get host => 'api.yuzid.uz';

  @Named("TestHost")
  String get testHost => 'api.yuzid.uz';

  @Named("Environment")
  bool get isTest => const bool.hasEnvironment("isTest");

  @singleton
  Future<Dio> getAuthorizedDioClient({
    @Named("Environment") required bool isTest,
    @Named("Host") required String host,
    @Named("TestHost") required String testHost,
  }) async {
    String _baseUrl = 'https://${isTest ? testHost : host}/';
    final authorizedDioClient = _createDioClient(_baseUrl);
    authorizedDioClient.interceptors.addAll([
      AuthorizedRequestInterceptor(
        authorizedDioClient,
      ),
    ]);
    return authorizedDioClient;
  }

  @Named("UnauthorizedClient")
  @singleton
  Future<Dio> getUnauthorizedDioClient({
    @Named("Environment") required bool isTest,
    @Named("Host") required String host,
    @Named("TestHost") required String testHost,
  }) async {
    String _baseUrl = 'https://${isTest ? testHost : host}/';
    final authorizedDioClient = _createDioClient(_baseUrl);
    authorizedDioClient.interceptors.addAll([
      AuthorizedRequestInterceptor(
        authorizedDioClient,
      ),
    ]);
    return authorizedDioClient;
  }

  Dio _createDioClient(String baseUrl) {
    final options = BaseOptions(
      baseUrl: baseUrl,
      receiveDataWhenStatusError: true,
      connectTimeout: const Duration(milliseconds: _requestTimeoutInMilliseconds),
      receiveTimeout: const Duration(milliseconds: _requestTimeoutInMilliseconds),
    );
    return Dio(options);
  }
}
